cmd

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrTokenRequired    = errors.New("token is required: use --token flag or RLGL_TOKEN env var")
	ErrClientIDRequired = errors.New("client-id is required: use --client-id flag or RLGL_CLIENT_ID env var")
)
var (
	Version   = "dev"
	CommitSHA = "unknown"
	BuildTime = "unknown"
)

Version information, set during build via ldflags.

var RootCmd = &cobra.Command{
	Use:   "rlgl",
	Short: "Current work-in-progress status dashboard",
	Long: `Status dashboard that shows what's currently
in progress as well as what upcoming items are in the user's
personal backlog.

rlgl reads from a local config file and syncs the status to a
remote web page.`,
}

RootCmd is the root command for rlgl.

Functions

func Execute

func Execute()

func InitConfig

func InitConfig(cmd *cobra.Command) (string, error)

Types

This section is empty.

Jump to